summaryrefslogtreecommitdiffstats
path: root/chrome/browser/profile.cc
diff options
context:
space:
mode:
authorsky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-11 15:22:32 +0000
committersky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-11 15:22:32 +0000
commitd8e41ed4a55e60be60d47de5bbcb8a027e85a879 (patch)
treee0feaa030fe3834c0fc871de7564ef74e9595b05 /chrome/browser/profile.cc
parent7903e0262e2dda44eaa186d126cf88e2cc1470eb (diff)
downloadchromium_src-d8e41ed4a55e60be60d47de5bbcb8a027e85a879.zip
chromium_src-d8e41ed4a55e60be60d47de5bbcb8a027e85a879.tar.gz
chromium_src-d8e41ed4a55e60be60d47de5bbcb8a027e85a879.tar.bz2
Renames BoomarkBarModel to BookmarkModel.
BUG=none TEST=none Review URL: http://codereview.chromium.org/1912 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@2057 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/profile.cc')
-rw-r--r--chrome/browser/profile.cc26
1 files changed, 9 insertions, 17 deletions
diff --git a/chrome/browser/profile.cc b/chrome/browser/profile.cc
index 1ca28fe..0ad41b6 100644
--- a/chrome/browser/profile.cc
+++ b/chrome/browser/profile.cc
@@ -11,7 +11,7 @@
#include "base/scoped_ptr.h"
#include "base/string_util.h"
#include "base/values.h"
-#include "chrome/browser/bookmarks/bookmark_bar_model.h"
+#include "chrome/browser/bookmarks/bookmark_model.h"
#include "chrome/browser/browser_list.h"
#include "chrome/browser/browser_process.h"
#include "chrome/browser/download_manager.h"
@@ -465,12 +465,8 @@ class OffTheRecordProfileImpl : public Profile,
return profile_->DidLastSessionExitCleanly();
}
- virtual bool HasBookmarkBarModel() {
- return profile_->HasBookmarkBarModel();
- }
-
- virtual BookmarkBarModel* GetBookmarkBarModel() {
- return profile_->GetBookmarkBarModel();
+ virtual BookmarkModel* GetBookmarkModel() {
+ return profile_->GetBookmarkModel();
}
#ifdef CHROME_PERSONALIZATION
@@ -610,11 +606,11 @@ ProfileImpl::~ProfileImpl() {
request_context_ = NULL;
}
// HistoryService may call into the BookmarkBarModel, as such we need to
// delete HistoryService before the BookmarkBarModel. The destructor for
// HistoryService will join with HistoryService's backend thread so that
// by the time the destructor has finished we're sure it will no longer call
// into the BookmarkBarModel.
history_service_ = NULL;
bookmark_bar_model_.reset();
@@ -724,7 +720,7 @@ HistoryService* ProfileImpl::GetHistoryService(ServiceAccessType sat) {
if (!history_service_created_) {
history_service_created_ = true;
scoped_refptr<HistoryService> history(new HistoryService(this));
- if (!history->Init(GetPath(), GetBookmarkBarModel()))
+ if (!history->Init(GetPath(), GetBookmarkModel()))
return NULL;
history_service_.swap(history);
@@ -836,13 +832,9 @@ bool ProfileImpl::DidLastSessionExitCleanly() {
return last_session_exited_cleanly_;
}
-bool ProfileImpl::HasBookmarkBarModel() {
- return bookmark_bar_model_.get() != NULL;
-}
-
-BookmarkBarModel* ProfileImpl::GetBookmarkBarModel() {
+BookmarkModel* ProfileImpl::GetBookmarkModel() {
if (!bookmark_bar_model_.get()) {
- bookmark_bar_model_.reset(new BookmarkBarModel(this));
+ bookmark_bar_model_.reset(new BookmarkModel(this));
bookmark_bar_model_->Load();
}
return bookmark_bar_model_.get();
@@ -610,11 +606,11 @@ ProfileImpl::~ProfileImpl() {
request_context_ = NULL;
}
- // HistoryService may call into the BookmarkBarModel, as such we need to
- // delete HistoryService before the BookmarkBarModel. The destructor for
+ // HistoryService may call into the BookmarkModel, as such we need to
+ // delete HistoryService before the BookmarkModel. The destructor for
// HistoryService will join with HistoryService's backend thread so that
// by the time the destructor has finished we're sure it will no longer call
@@ -610,11 +606,11 @@ ProfileImpl::~ProfileImpl() {
// HistoryService will join with HistoryService's backend thread so that
// by the time the destructor has finished we're sure it will no longer call
- // into the BookmarkBarModel.
+ // into the BookmarkModel.
history_service_ = NULL;
bookmark_bar_model_.reset();